Animation

Struct Animation 

pub struct Animation {
    pub file_id: String,
    pub thumb: Option<Box<PhotoSize>>,
    pub file_name: Option<String>,
    pub mime_type: Option<String>,
    pub file_size: Option<i64>,
}
You can provide an animation for your game so that it looks stylish in chats (check out Lumberjack for an example). This object represents an animation file to be displayed in the message containing a game. See https://core.telegram.org/bots/api#game See https://t.me/gamebot See https://core.telegram.org/bots/api#games

Fields

file_id: String

Unique file identifier

thumb: Option<Box<PhotoSize>>

Animation thumbnail as defined by sender

file_name: Option<String>

Original animation filename as defined by sender

mime_type: Option<String>

MIME type of the file as defined by sender

file_size: Option<i64>

File size