pub struct Chat {Show 13 fields
pub id: i64,
pub type_tl: String,
pub title: Option<String>,
pub username: Option<String>,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub all_members_are_administrators: Option<bool>,
pub photo: Option<Box<ChatPhoto>>,
pub description: Option<String>,
pub invite_link: Option<String>,
pub pinned_message: Option<Box<Message>>,
pub sticker_set_name: Option<String>,
pub can_set_sticker_set: Option<bool>,
}Expand description
This object represents a chat.
Fields
id: i64Unique identifier for this chat. This number may be greater than 32 bits and some programming languages may have difficulty/silent defects in interpreting it. But it is smaller than 52 bits, so a signed 64 bit integer or double-precision float type are safe for storing this identifier.
type_tl: StringType of chat, can be either “private”, “group”, “supergroup” or “channel”
title: Option<String>Title, for supergroups, channels and group chats
username: Option<String>Username, for private chats, supergroups and channels if available
first_name: Option<String>First name of the other party in a private chat
last_name: Option<String>Last name of the other party in a private chat
all_members_are_administrators: Option<bool>True if a group has ‘All Members Are Admins’ enabled.
photo: Option<Box<ChatPhoto>>Chat photo. Returned only in getChat. See https://core.telegram.org/bots/api#getchat
description: Option<String>Description, for supergroups and channel chats. Returned only in getChat. See https://core.telegram.org/bots/api#getchat
invite_link: Option<String>Chat invite link, for supergroups and channel chats. Returned only in getChat. See https://core.telegram.org/bots/api#getchat
pinned_message: Option<Box<Message>>Pinned message, for supergroups and channel chats. Returned only in getChat. See https://core.telegram.org/bots/api#getchat
sticker_set_name: Option<String>For supergroups, name of group sticker set. Returned only in getChat. See https://core.telegram.org/bots/api#getchat
can_set_sticker_set: Option<bool>True, if the bot can change the group sticker set. Returned only in getChat. See https://core.telegram.org/bots/api#getchat