pub struct InputMediaPhoto {
pub type_tl: String,
pub media: String,
pub caption: Option<String>,
pub parse_mode: Option<String>,
}Expand description
Represents a photo to be sent.
Fields
type_tl: StringType of the result, must be photo
media: StringFile to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files » See https://core.telegram.org/bots/api#sending-files
caption: Option<String>Caption of the photo to be sent, 0-200 characters
parse_mode: Option<String>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption. See https://core.telegram.org/bots/api#markdown-style See https://core.telegram.org/bots/api#html-style See https://core.telegram.org/bots/api#formatting-options