pub struct Sticker {
pub file_id: String,
pub width: i64,
pub height: i64,
pub thumb: Option<Box<PhotoSize>>,
pub emoji: Option<String>,
pub set_name: Option<String>,
pub mask_position: Option<Box<MaskPosition>>,
pub file_size: Option<i64>,
}Expand description
This object represents a sticker.
Fields
file_id: StringUnique identifier for this file
width: i64Sticker width
height: i64Sticker height
thumb: Option<Box<PhotoSize>>Sticker thumbnail in the .webp or .jpg format
emoji: Option<String>Emoji associated with the sticker
set_name: Option<String>Name of the sticker set to which the sticker belongs
mask_position: Option<Box<MaskPosition>>For mask stickers, the position where the mask should be placed
file_size: Option<i64>File size